==> openshift-client-4.13.0-sources.jar: io/fabric8/openshift/client/handlers/AppliedClusterResourceQuotaHandler.java <==

                            

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.AppliedClusterResourceQuotaOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.AppliedClusterResourceQuota;
import io.fabric8.openshift.api.model.AppliedClusterResourceQuotaBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class AppliedClusterResourceQuotaHandler implements ResourceHandler<AppliedClusterResourceQuota, AppliedClusterResourceQuotaBuilder> {

  @Override
  public String getKind() {
    return AppliedClusterResourceQuota.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "quota.openshift.io/v1";
    }

  @Override
  public AppliedClusterResourceQuota create(OkHttpClient client, Config config, String namespace, AppliedClusterResourceQuota item) {
    return new AppliedClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public AppliedClusterResourceQuota replace(OkHttpClient client, Config config, String namespace, AppliedClusterResourceQuota item) {
    return new AppliedClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public AppliedClusterResourceQuota reload(OkHttpClient client, Config config, String namespace, AppliedClusterResourceQuota item) {
    return new AppliedClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public AppliedClusterResourceQuotaBuilder edit(AppliedClusterResourceQuota item) {
    return new AppliedClusterResourceQuotaBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, AppliedClusterResourceQuota item) {
    return new AppliedClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).withPropagationPolicy(propagationPolicy).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, AppliedClusterResourceQuota item, Watcher<AppliedClusterResourceQuota> watcher) {
    return new AppliedClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, AppliedClusterResourceQuota item, String resourceVersion, Watcher<AppliedClusterResourceQuota> watcher) {
    return new AppliedClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, AppliedClusterResourceQuota item, ListOptions options, Watcher<AppliedClusterResourceQuota> watcher) {
  return new AppliedClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public AppliedClusterResourceQuota waitUntilReady(OkHttpClient client, Config config, String namespace, AppliedClusterResourceQuota item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new AppliedClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public AppliedClusterResourceQuota waitUntilCondition(OkHttpClient client, Config config, String namespace, AppliedClusterResourceQuota item, Predicate<AppliedClusterResourceQuota> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new AppliedClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> openshift-client-5.2.1-sources.jar: io/fabric8/openshift/client/handlers/AppliedClusterResourceQuotaHandler.java <==

                            

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.AppliedClusterResourceQuotaOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.AppliedClusterResourceQuota;
import io.fabric8.openshift.api.model.AppliedClusterResourceQuotaBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class AppliedClusterResourceQuotaHandler implements ResourceHandler<AppliedClusterResourceQuota, AppliedClusterResourceQuotaBuilder> {

  @Override
  public String getKind() {
    return AppliedClusterResourceQuota.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "quota.openshift.io/v1";
    }

  @Override
  public AppliedClusterResourceQuota create(OkHttpClient client, Config config, String namespace, AppliedClusterResourceQuota item, boolean dryRun) {
    return new AppliedClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).dryRun(dryRun).create();
  }

  @Override
  public AppliedClusterResourceQuota replace(OkHttpClient client, Config config, String namespace, AppliedClusterResourceQuota item, boolean dryRun) {
    return new AppliedClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).dryRun(dryRun).replace(item);
  }

  @Override
  public AppliedClusterResourceQuota reload(OkHttpClient client, Config config, String namespace, AppliedClusterResourceQuota item) {
    return new AppliedClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public AppliedClusterResourceQuotaBuilder edit(AppliedClusterResourceQuota item) {
    return new AppliedClusterResourceQuotaBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, long gracePeriodSeconds, AppliedClusterResourceQuota item, boolean dryRun) {
    return new AppliedClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).dryRun(dryRun).withPropagationPolicy(propagationPolicy).withGracePeriod(gracePeriodSeconds).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, AppliedClusterResourceQuota item, Watcher<AppliedClusterResourceQuota> watcher) {
    return new AppliedClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, AppliedClusterResourceQuota item, String resourceVersion, Watcher<AppliedClusterResourceQuota> watcher) {
    return new AppliedClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, AppliedClusterResourceQuota item, ListOptions options, Watcher<AppliedClusterResourceQuota> watcher) {
  return new AppliedClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public AppliedClusterResourceQuota waitUntilReady(OkHttpClient client, Config config, String namespace, AppliedClusterResourceQuota item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new AppliedClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public AppliedClusterResourceQuota waitUntilCondition(OkHttpClient client, Config config, String namespace, AppliedClusterResourceQuota item, Predicate<AppliedClusterResourceQuota> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new AppliedClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}
